# Importing, Exporting, and Linking Fact Sheets and Jira Work Items
### On this page
  * [Importing Jira Work Items as Child Initiative Fact Sheets](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues#importing-jira-work-items-as-child-initiative-fact-sheets)
  * [Exporting Initiative Fact Sheets as Jira Work Items](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues#exporting-initiative-fact-sheets-as-jira-work-items)
  * [Linking an Existing Initiative Fact Sheet to an Existing Jira Work Item](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues#linking-an-existing-initiative-fact-sheet-to-an-existing-jira-work-item)
  * [Searching and Filtering for Jira Work Items](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues#searching-and-filtering-for-jira-work-items)
  * [Setting Up Automated Import Rules](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues#setting-up-automated-import-rules)
  * [Editing Import Rules](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues#editing-import-rules)
  * [Turning Off Import Rules](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues#turning-off-import-rules)
  * [Deleting Import Rules](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues#deleting-import-rules)


Set up syncing between SAP LeanIX and Jira by creating new fact sheets or Jira work items, or by linking existing items across both tools.
Learn how to sync initiative data between SAP LeanIX and Jira. You can define which Jira projects map to which SAP LeanIX initiatives, and filter by Jira instance or project to refine the scope. This lets you control which work items are included in your architecture workspace, ensuring only relevant data is synced.
